.. figure:: http://noble.gs.washington.edu/proj/metapeptide/images/sixgill_logo.png
   :alt: 

Sixgill
=======

Six-frame Genome-Inferred Libraries for LC-MS/MS

What is Sixgill?
----------------

Sixgill is a tool for using shotgun metagenomics sequencing reads to
construct databases of 'metapeptides': short protein fragments for
database search of LC-MS/MS metaproteomics data. A comprehensive set of
resources for building and using metapeptide databases is
`here <http://noble.gs.washington.edu/proj/metapeptide/>`__.

Required Python versions
------------------------

Sixgill supports Python 2.7

Project dependencies
--------------------

Sixgill uses the following python packages:

-  `biopython <http://biopython.org>`__
-  `pysam <https://code.google.com/archive/p/pysam/>`__

Installation
------------

-  `Get pip <https://pip.pypa.io/en/stable/installing/>`__, if you don’t
   have it yet.

-  Install Sixgill and its dependencies:

   pip install biopython pysam sixgill

Documentation
-------------

The `Sixgill wiki <https://github.com/dhmay/sixgill/wiki>`__ contains
more detailed information on using Sixgill.
